@@ -101,4 +101,27 @@ def test_country():
     assert len(voc)
     voc2 = Vocabulary(date, lang="Es")
     print(len(voc2), len(voc))
-    assert voc2.voc.update_calls > voc.voc.update_calls
\ No newline at end of file
+    assert voc2.voc.update_calls > voc.voc.update_calls
+
+
+def test_vocabulary_dict():
+    class D(object):
+        def __init__(self, year, month, day):
+            self.year = year
+            self.month = month
+            self.day = day
+
+    voc = Vocabulary(dict(year=2020, month=7, day=21))
+    assert voc["buenos"]
+    voc2 = Vocabulary(D(2020, 7, 21))
+    assert voc["buenos"] == voc2["buenos"]
+
+
+def test_vocabulary_data_lst():
+    import pandas as pd
+
+    d = list(pd.date_range("2020-07-20", "2020-07-21"))
+    print(len(d))
+    vocs = Vocabulary(d)
+    assert vocs["buenos"]
+    assert len(d) == 2
\ No newline at end of file
